@@ -158,7 +158,7 @@ def upload_loop():
                                         })
                 os.remove(name)
                 os.remove(mp4_name)
-            except MinioException as err:
+            except Exception as err:
                 logger.exception(err)
                 logger.exception("failed to process %s", name)
         else:
